@@ -19,12 +19,14 @@
 
 #include "deletejob.h"
 
+#include <KLocalizedString>
+
 #include "job_p.h"
 #include "message_p.h"
 #include "session_p.h"
 #include "rfccodecs.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class DeleteJobPrivate : public JobPrivate
 {
@@ -36,10 +38,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 DeleteJob::DeleteJob(Session *session)
-    : Job(*new DeleteJobPrivate(session, "Delete"))
+    : Job(*new DeleteJobPrivate(session, i18n("Delete")))
 {
 }
 
@@ -50,7 +52,7 @@ DeleteJob::~DeleteJob()
 void DeleteJob::doStart()
 {
     Q_D(DeleteJob);
-    d->sendCommand("DELETE", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
+    d->tags << d->sessionInternal()->sendCommand("DELETE", '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
 }
 
 void DeleteJob::setMailBox(const QString &mailBox)
